Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Simple Email Service - Mail Manager.

Actions, resources, and condition keys for Amazon Simple Email Service - Mail Manager - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Simple Email Service - Mail Manager

Amazon Simple Email Service - Mail Manager (service prefix: `ses` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Simple Email Service - Mail Manager
- Resource types defined by Amazon Simple Email Service - Mail Manager
- Condition keys for Amazon Simple Email Service - Mail Manager

## Actions defined by Amazon Simple Email Service - Mail Manager

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateAddonInstance | Grants permission to create an addon instance | Write |  | aws:RequestTag/${TagKey} aws:TagKeys ses:AddonSubscriptionArn |
CreateAddonSubscription | Grants permission to create an addon subscription | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateArchive | Grants permission to create an archive | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateIngressPoint | Grants permission to create an ingress point | Write |  | aws:RequestTag/${TagKey} aws:TagKeys ses:MailManagerRuleSetArn ses:MailManagerTrafficPolicyArn | iam:CreateServiceLinkedRole
CreateRelay | Grants permission to create a SMTP relay | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateRuleSet | Grants permission to create a rule set | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateTrafficPolicy | Grants permission to create a traffic policy | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
DeleteAddonInstance | Grants permission to delete an addon instance | Write | addon-instance* |  |
| aws:RequestTag/${TagKey} |
DeleteAddonSubscription | Grants permission to delete an addon subscription | Write | addon-subscription* |  |
| aws:RequestTag/${TagKey} |
DeleteArchive | Grants permission to delete an archive | Write | mailmanager-archive* |  |
| aws:RequestTag/${TagKey} |
DeleteIngressPoint | Grants permission to delete an ingress point | Write | mailmanager-ingress-point* |  |
| aws:RequestTag/${TagKey} |
DeleteRelay | Grants permission to delete a SMTP relay | Write | mailmanager-smtp-relay* |  |
| aws:RequestTag/${TagKey} |
DeleteRuleSet | Grants permission to delete a rule set | Write | mailmanager-rule-set* |  |
| aws:RequestTag/${TagKey} |
DeleteTrafficPolicy | Grants permission to delete a traffic point | Write | mailmanager-traffic-policy* |  |
| aws:RequestTag/${TagKey} |
GetAddonInstance | Grants permission to get information about an addon instance | Read | addon-instance* |  |
| aws:RequestTag/${TagKey} |
GetAddonSubscription | Grants permission to get information about an addon subscription | Read | addon-subscription* |  |
| aws:RequestTag/${TagKey} |
GetArchive | Grants permission to get information about an archive | Read | mailmanager-archive* |  |
| aws:RequestTag/${TagKey} |
GetArchiveExport | Grants permission to get information about an archive export | Read | mailmanager-archive* |  |
GetArchiveMessage | Grants permission to retrieve archived message | Read | mailmanager-archive* |  |
GetArchiveMessageContent | Grants permission to retrieve archived message content | Read | mailmanager-archive* |  |
GetArchiveSearch | Grants permission to get information about a search | Read | mailmanager-archive* |  |
GetArchiveSearchResults | Grants permission to get information about search results | Read | mailmanager-archive* |  |
GetIngressPoint | Grants permission to get information about an ingress point | Read | mailmanager-ingress-point* |  |
| aws:RequestTag/${TagKey} |
GetRelay | Grants permission to get information about a SMTP relay | Read | mailmanager-smtp-relay* |  |
| aws:RequestTag/${TagKey} |
GetRuleSet | Grants permission to get information about a rule set | Read | mailmanager-rule-set* |  |
| aws:RequestTag/${TagKey} |
GetTrafficPolicy | Grants permission to get information about a traffic policy | Read | mailmanager-traffic-policy* |  |
| aws:RequestTag/${TagKey} |
ListAddonInstances | Grants permission to list all of the addon instances associated with your account | List |  |  |
ListAddonSubscriptions | Grants permission to list all of the addon subscriptions associated with your account | List |  |  |
ListArchiveExports | Grants permission to list all of the archive exports associated with your account | List |  |  |
ListArchiveSearches | Grants permission to list all of the archive searches associated with your account | List |  |  |
ListArchives | Grants permission to list all of the archives associated with your account | List |  |  |
ListIngressPoints | Grants permission to list all of the ingress points associated with your account | List |  |  |
ListRelays | Grants permission to list all of the SMTP relays associated with your account | List |  |  |
ListRuleSets | Grants permission to list all of the rule sets associated with your account | List |  |  |
ListTagsForResource | Grants permission to list all of the tags associated with the resource | Read | addon-instance |  |
addon-subscription |  |
mailmanager-archive |  |
mailmanager-ingress-point |  |
mailmanager-rule-set |  |
mailmanager-smtp-relay |  |
mailmanager-traffic-policy |  |
ListTrafficPolicies | Grants permission to list all of the traffic policies associated with your account | List |  |  |
StartArchiveExport | Grants permission to start an archive export | Write | mailmanager-archive* |  |
StartArchiveSearch | Grants permission to start an archive search | Write | mailmanager-archive* |  |
StopArchiveExport | Grants permission to stop archive export | Write | mailmanager-archive* |  |
StopArchiveSearch | Grants permission to stop archive search | Write | mailmanager-archive* |  |
TagResource | Grants permission to add one or more tags (keys and values) to a specified resource | Tagging | addon-instance |  |
addon-subscription |  |
mailmanager-archive |  |
mailmanager-ingress-point |  |
mailmanager-rule-set |  |
mailmanager-smtp-relay |  |
mailmanager-traffic-policy |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to remove one or more tags (keys and values) from a specified resource | Tagging | addon-instance |  |
addon-subscription |  |
mailmanager-archive |  |
mailmanager-ingress-point |  |
mailmanager-rule-set |  |
mailmanager-smtp-relay |  |
mailmanager-traffic-policy |  |
| aws:TagKeys |
UpdateArchive | Grants permission to update an archive | Write | mailmanager-archive* |  |
| aws:RequestTag/${TagKey} |
UpdateIngressPoint | Grants permission to update an ingress point | Write | mailmanager-ingress-point* |  |
| aws:RequestTag/${TagKey} ses:MailManagerTrafficPolicyArn ses:MailManagerRuleSetArn |
UpdateRelay | Grants permission to update a SMTP relay | Write | mailmanager-smtp-relay* |  |
| aws:RequestTag/${TagKey} |
UpdateRuleSet | Grants permission to update a rule set | Write | mailmanager-rule-set* |  |
| aws:RequestTag/${TagKey} |
UpdateTrafficPolicy | Grants permission to update a traffic policy | Write | mailmanager-traffic-policy* |  |
| aws:RequestTag/${TagKey} |

## Resource types defined by Amazon Simple Email Service - Mail Manager

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
addon-instance | `arn:$ { Partition}:ses:$ { Region}:$ { Account}:addon-instance/$ { AddonInstanceId}` | aws:ResourceTag/${TagKey}
addon-subscription | `arn:$ { Partition}:ses:$ { Region}:$ { Account}:addon-subscription/$ { AddonSubscriptionId}` | aws:ResourceTag/${TagKey}
mailmanager-archive | `arn:$ { Partition}:ses:$ { Region}:$ { Account}:mailmanager-archive/$ { ArchiveId}` | aws:ResourceTag/${TagKey}
mailmanager-ingress-point | `arn:$ { Partition}:ses:$ { Region}:$ { Account}:mailmanager-ingress-point/$ { IngressPointId}` | aws:ResourceTag/${TagKey} ses:MailManagerIngressPointType
mailmanager-smtp-relay | `arn:$ { Partition}:ses:$ { Region}:$ { Account}:mailmanager-smtp-relay/$ { RelayId}` | aws:ResourceTag/${TagKey}
mailmanager-rule-set | `arn:$ { Partition}:ses:$ { Region}:$ { Account}:mailmanager-rule-set/$ { RuleSetId}` | aws:ResourceTag/${TagKey}
mailmanager-traffic-policy | `arn:$ { Partition}:ses:$ { Region}:$ { Account}:mailmanager-traffic-policy/$ { TrafficPolicyId}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Simple Email Service - Mail Manager

Amazon Simple Email Service - Mail Manager defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by the presence of tag keys in the request | ArrayOfString
ses:AddonSubscriptionArn | Filters access by SES Addon Subscription ARN | ARN
ses:MailManagerIngressPointType | Filters access by SES Mail Manager ingress point type, for example OPEN or AUTH | String
ses:MailManagerRuleSetArn | Filters access by SES Mail Manager rule set ARN | ARN
ses:MailManagerTrafficPolicyArn | Filters access by SES Mail Manager traffic policy ARN | ARN

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.